@@ -15,10 +15,6 @@
 """Utility routines for constructing a Google Genomics Pipelines v2 API request.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from . import google_v2_versions
 
 _API_VERSION = None
