@@ -82,8 +82,7 @@ class StubJobProvider(base.JobProvider):
                        labels=None,
                        create_time_min=None,
                        create_time_max=None,
-                       max_tasks=0,
-                       verbose=True):
+                       max_tasks=0):
     """Return a list of operations. See base.py for additional detail."""
     statuses = None if statuses == {'*'} else statuses
     user_ids = None if user_ids == {'*'} else user_ids
